var ParametrizacaoAplicativos = function (General, templateManager, parametrizacaoAplicativosService, ScreenService, MessageService, Colors) {

    var self = this;
    
    this.checkMaxApps = function () {
        let mainWidget = templateManager.container.getWidget('applist');
        parametrizacaoAplicativosService.checkMaxApps().then(resp => {
            mainWidget.getAction('ADD').isVisible = (resp.dataset.remaningApps.length > 0);
        });
    };

    this.editAppConfig = function () {
        let mainWidget = templateManager.container.getWidget('applist');
        General.edit(mainWidget);
        mainWidget.currentRow.__createdLocal = false;
        mainWidget.currentRow.__is_new = false;
    };

    this.add = function (widget) {
        templateManager.container.getWidget('applist').newRow();
        widget.getField("URLLOGO").noFileSelectedText = "";
    };

    this.remove = function () {
        let mainWidget = templateManager.container.getWidget('applist');
        MessageService.confirmMessageByCode("deleteQuestion").then(() => {
			parametrizacaoAplicativosService.deleteRow(mainWidget.currentRow).then(() => {
				ScreenService.closeSwipe().then(() => {
                    mainWidget.reload();
                    MessageService.notificationMessageByCode("successOnRemove", null, { type: "success" });
                });
			});
		});
    };

    this.save = function () {
        let mainWidget = templateManager.container.getWidget('applist');
        if (mainWidget.isValid()) {
            if(mainWidget.currentRow.DSCORPRIMARIA != "" && mainWidget.currentRow.DSCORPRIMARIA != null){
                mainWidget.currentRow.DSCORPRIMARIA = TransformColor(mainWidget.currentRow.DSCORPRIMARIA);
            }
            parametrizacaoAplicativosService.saveRow(mainWidget.currentRow).then((response) => {
                let rowSaved = response.dataset.rowSaved[0];
                MessageService.notificationMessageByCode("successOnSave", null, {type: "success"});
                mainWidget.currentRow = rowSaved;
                mainWidget.currentRow.__createdLocal = false;
                mainWidget.currentRow.__is_new = false;
                self.trataCor(mainWidget);
                mainWidget.view();
                ScreenService.closeSwipe();
                mainWidget.reload();
                this.generateQRCode(mainWidget);
            }).catch((response) => {
                ScreenService.showMessage(response.data.error);
            });
        }
    };

    this.checkFileExtension = function () {
        let mainWidget = templateManager.container.getWidget('applist');
        setTimeout(()=>{
            let logo = mainWidget.getField('URLLOGO').value();
            if (logo.length > 0 && !(logo[0].name.split('.')[1] === 'jpg' || logo[0].name.split('.')[1] === 'jpeg')) {
                MessageService.showMessageByCode("imageInvalidFormat", null, {type: "error"});
                mainWidget.getField('URLLOGO').value(null);
            }
        },350);
    };
    
    this.generateQRCode = (widget) => {
        setTimeout(() => {
            let imgs = document.getElementsByTagName("img");
            let imageField = document.getElementById("span-field-QRCODE");

            for (let i=0; i<imgs.length; i++) {
                if (imgs[i].alt == "qrCodeGenerated")
                    imageField.removeChild(imgs[i]);
            }
            
            if(widget.currentRow.IDAPLICATIVO == "MYORDER" || widget.currentRow.IDAPLICATIVO == "APPROVE" || widget.currentRow.IDAPLICATIVO == "OPERATIONS" || widget.currentRow.IDAPLICATIVO == "MYQUEST" ){
                
                let qrCodeURL = widget.currentRow.DSDNS+";"+getLocalVar("NRORG");
                
    
                new QRCode(imageField.id, qrCodeURL);
    
                imageField.style.textAlign = "center";
                imageField.style.marginTop = "20px";
                
                widget.getAction("downloadQRCode").isVisible = true;
            }else{
                widget.getAction("downloadQRCode").isVisible = false;
            }

            templateManager.updateTemplate();
            
        }, 300);
    };
    
    this.trataCor = function(owner) {
        let currentRow = owner.currentRow;
         
        owner.dataSource.data.forEach(function(row) {
            if(row.DSCORPRIMARIA != null && row.__treated == undefined){
                    row.DSCORPRIMARIA = Colors.TColorToHex(row.DSCORPRIMARIA);
                    row.__treated = true;
            }        
        });
        if(currentRow.DSCORPRIMARIA != null && currentRow.__treated == undefined){
            currentRow.DSCORPRIMARIA = Colors.TColorToHex(currentRow.DSCORPRIMARIA);
            currentRow.__treated = true;
        }
    };

    function TransformColor(Color) {
        let r, g, b, h;
        if (Color.toString().charAt(0) != '#') {
            r = Color._r.toString();
            g = Color._g.toString();
            b = Color._b.toString();
            if (r.indexOf('.') != -1) {
                r = r.substr(0, r.indexOf('.'));
            }
            if (g.indexOf('.') != -1) {
                g = g.substr(0, g.indexOf('.'));
            }
            if (b.indexOf('.') != -1) {
                b = b.substr(0, b.indexOf('.'));
            }
            r = parseInt(r);
            g = parseInt(g);
            b = parseInt(b);
        }
        else {
            h = Color.substring(1, 7);
            r = parseInt((h).substring(0, 2), 16);
            g = parseInt((h).substring(2, 4), 16);
            b = parseInt((h).substring(4, 6), 16);
        }

        return r | (g << 8) | (b << 16);
    }
    
    this.setCor = function(row, fieldName, element) {
        if (row[fieldName]) {
            if (typeof row[fieldName] === "number") {
                row[fieldName] = Colors.TColorToHex(row[fieldName]);
            }
            else if (typeof row[fieldName] === "object") {
                row[fieldName] = Colors.TColorToHex(TransformColor(row[fieldName]));
            }
            setTimeout(function() {
                var column = element.find('.td:eq(3)');
                if(column.context.className.indexOf('td') !== -1){
                    var styles = column.context.getAttribute('style') || "";
                    
                    styles = styles.split(';');
                    styles = styles.filter(s => !s.includes('background'));
                    styles.push('background: '+row[fieldName] + ' !important');
                    styles = styles.join(';');
                    column.context.setAttribute('style', styles);
                    column.context.textContent = '';
                }                
            }, 100);
        }
    };
    
    this.download = function() {
        var link = document.createElement("a");
        link.download = "QrCode";
        link.href = getLocalVar("qrcode_uri");
        document.body.appendChild(link);
        link.click();
        document.body.removeChild(link);
    };
};

Configuration(function (ContextRegister) {
    ContextRegister.register('ParametrizacaoAplicativos', ParametrizacaoAplicativos);
});